package com.ruoyi.sim.mapper;

import java.util.List;

import com.ruoyi.sim.domain.RealExamCollectionDept;

/**
 * 考试集合班级关联Mapper接口
 *
 * @author tom
 * @date 2024-12-13
 */
public interface RealExamCollectionDeptMapper {
    /**
     * 查询考试集合班级关联
     *
     * @param relId 考试集合班级关联主键
     * @return 考试集合班级关联
     */
    public RealExamCollectionDept selectRealExamCollectionDeptByRelId(Long relId);

    /**
     * 查询考试集合班级关联列表
     *
     * @param realExamCollectionDept 考试集合班级关联
     * @return 考试集合班级关联集合
     */
    public List<RealExamCollectionDept> selectRealExamCollectionDeptList(RealExamCollectionDept realExamCollectionDept);

    /**
     * 新增考试集合班级关联
     *
     * @param realExamCollectionDept 考试集合班级关联
     * @return 结果
     */
    public int insertRealExamCollectionDept(RealExamCollectionDept realExamCollectionDept);

    /**
     * 修改考试集合班级关联
     *
     * @param realExamCollectionDept 考试集合班级关联
     * @return 结果
     */
    public int updateRealExamCollectionDept(RealExamCollectionDept realExamCollectionDept);

    /**
     * 删除考试集合班级关联
     *
     * @param relId 考试集合班级关联主键
     * @return 结果
     */
    public int deleteRealExamCollectionDeptByRelId(Long relId);

    /**
     * 批量删除考试集合班级关联
     *
     * @param relIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRealExamCollectionDeptByRelIds(Long[] relIds);
}
